#
# spec file for package kconfig
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum   5
%define _tar_path 5.55
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kconfig
Version:        5.55.0
Release:        lp151.2.5.1
Summary:        Advanced configuration system
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FEATURE-OPENSUSE
Patch0:         kconfig-desktop-translations.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Security-remove-support-for-.-in-config-keys-with-e-.patch
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(Qt5Core) >= 5.6.0
BuildRequires:  cmake(Qt5DBus) >= 5.6.0
BuildRequires:  cmake(Qt5Gui) >= 5.6.0
BuildRequires:  cmake(Qt5Xml) >= 5.6.0
%if %{with lang}
BuildRequires:  cmake(Qt5LinguistTools) >= 5.6.0
%endif

%description
KConfig provides an advanced configuration system. It is made of two parts:
KConfigCore and KConfigGui.

KConfigCore provides access to the configuration files themselves. It features:

- centralized definition: define your configuration in an XML file and use
`kconfig_compiler` to generate classes to read and write configuration entries.

- lock-down (kiosk) support.

KConfigGui provides a way to hook widgets to the configuration so that they are
automatically initialized from the configuration and automatically propagate
their changes to their respective configuration files.

%package -n libKF5ConfigCore%{sonum}
Summary:        System for configuration files
Group:          System/GUI/KDE
%requires_ge    libQt5Core5
Recommends:     kconf_update5 = %{version}
%if %{with lang}
Recommends:     libKF5ConfigCore%{sonum}-lang = %{version}
%endif

%description -n libKF5ConfigCore%{sonum}
KConfig provides an advanced configuration system. It is made of two parts:
KConfigCore and KConfigGui.

KConfigCore provides access to the configuration files themselves.

%package -n libKF5ConfigGui%{sonum}
Summary:        Widgets hooks for configuration entities
Group:          System/GUI/KDE
%requires_ge    libKF5ConfigCore5
%requires_ge    libQt5Core5
%requires_ge    libQt5Gui5
%requires_ge    libQt5Xml5

%description -n libKF5ConfigGui%{sonum}
KConfigGui provides a way to hook widgets to the configuration so that they are
automatically initialized from the configuration and automatically propagate
their changes to their respective configuration files.

%package -n kconf_update5
Summary:        Configuration file access
Group:          System/GUI/KDE
Requires:       libKF5ConfigCore%{sonum} = %{version}

%description -n kconf_update5
KConfig provides an advanced configuration system. It is made of two parts:
KConfigCore and KConfigGui.

This package contains the kconf_update tool.

%package devel
Summary:        KConfig Development files
Group:          Development/Libraries/KDE
Requires:       extra-cmake-modules
Requires:       kconf_update5 = %{version}
Requires:       libKF5ConfigCore%{sonum} = %{version}
Requires:       libKF5ConfigGui%{sonum} = %{version}
Requires:       cmake(Qt5Xml) >= 5.6.0

%description devel
KConfig provides an advanced configuration system. It is made of two parts:
KConfigCore and KConfigGui.

KConfigCore provides access to the configuration files themselves. It features:

- centralized definition: define your configuration in an XML file and use
`kconfig_compiler` to generate classes to read and write configuration entries.

- lock-down (kiosk) support.

KConfigGui provides a way to hook widgets to the configuration so that they are
automatically initialized from the configuration and automatically propagate
their changes to their respective configuration files. Development files.

%lang_package -n libKF5ConfigCore%{sonum}

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%if 0%{?suse_version} == 1500
sed -i -e "s/^set *(REQUIRED_QT_VERSION 5.10.0)$/set(REQUIRED_QT_VERSION 5.9.0)/" CMakeLists.txt
%endif

%build
  %cmake_kf5 -d build -- -Dlconvert_executable=%{_kf5_libdir}/qt5/bin/lconvert
  %make_jobs

%install
  %kf5_makeinstall -C build
  %fdupes %{buildroot}

%if %{with lang}
%find_lang %{name}5 --with-qt --without-mo
%endif

%post -n libKF5ConfigCore%{sonum} -p /sbin/ldconfig
%postun -n libKF5ConfigCore%{sonum} -p /sbin/ldconfig
%post -n libKF5ConfigGui%{sonum} -p /sbin/ldconfig
%postun -n libKF5ConfigGui%{sonum} -p /sbin/ldconfig

%if %{with lang}
%files -n libKF5ConfigCore%{sonum}-lang -f %{name}5.lang
%endif

%files -n libKF5ConfigCore%{sonum}
%license COPYING*
%doc README*
%{_kf5_bindir}/k*config5
%{_kf5_libdir}/libKF5ConfigCore.so.*

%files -n libKF5ConfigGui%{sonum}
%license COPYING*
%doc README*
%{_kf5_libdir}/libKF5ConfigGui.so.*

%files -n kconf_update5
%license COPYING*
%doc README*
%dir %{_kf5_libexecdir}
%{_kf5_libexecdir}/kconf_update

%files devel
%{_kf5_libexecdir}/kconfig_compiler_kf5
%{_kf5_libdir}/libKF5ConfigCore.so
%{_kf5_libdir}/libKF5ConfigGui.so
%{_kf5_libdir}/cmake/KF5Config/
%{_kf5_includedir}/
%{_kf5_mkspecsdir}/qt_KConfigCore.pri
%{_kf5_mkspecsdir}/qt_KConfigGui.pri

%changelog
* Wed Aug  7 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to drop involuntary command execution (boo#1144600, CVE-2019-14744):
  * 0001-Security-remove-support-for-.-in-config-keys-with-e-.patch
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * [API dox] Include kconfig_compiler/README.dox for QCH generation
  * kconfig_compiler: delete the assignment operator and copy constructor
  * KEmailSettings: Delete copy constructor and assignment operator
  * KonfUpdate: delete copy constructor and assignment operator
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix doxygen markup in KConfigWatcher
  * Fix a regression introduced in 6a1852
  * Fix build without D-Bus
  * Deduplicate reference value
  * Remove unneeded qWarning
  * Escape bytes that are larger than or equal to 127 in config files
  * Fix documentation, QValueList isn't a thing anymore
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summaries.
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * normalize signal/slot
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Remove unused variable
  * Fix logic error in NotifyFlag testing
  * Set explicit arg type in QCOMPARE
  * Fix compilation without D-Bus
  * Add mechanism to notify other clients of config changes over DBus
  * Expose getter method for KConfig::addConfigSources
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Remove misleading use of KDE_INSTALL_PYTHONBINDINGSDIR
  * Fix issue when reading path lists
  * API dox: 0 -> nullptr
  * kcfg_compiler now documents valid inputs for its 'Color' type
  * whitespace cleanup
  * Port deprecated method + use strict compile flags
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Remove warning about old kiosk feature that no longer applies.
  * Set system default shortcut Ctrl+0 for "Actual Size" action
  * Fix cleanup of kconfigtest kdeglobals
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove unused include
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * KConfigCompiler_Test: Update test_signal.h.ref to follow the generated file
  * kcfg.xsd - do not require a kcfgfile element
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Use override
  * Warning--
- Refreshed patches:
  * kconfig-desktop-translations.patch
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Fix autotest
  * Remove useless QT_VERSION_CHECK
  * Remove not necessary QtCore and co
- Refreshed patches:
  * kconfig-desktop-translations.patch
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Save some memory allocations by using the right API
  * Export kconf_update with tooling
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Use Ctrl+Shift+, as the standard shortcut for "Configure <Program>"
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Remove cmake warning about generating moc file
  * API docs: Sergio suggested create(), more readable than winId()
  * API docs: full working code, including workaround for Qt issue...
  * API docs: explain how to use KWindowConfig from a dialog constructor.
  * Deprecate KDesktopFile::sortOrder()
  * Fix the result of KDesktopFile::sortOrder()
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * KConfig: fix autotest on CI with trailing slash in HOME.
  * Repair broken test after commit ee2b394599.
  * Fix some clazy warning
  * Use Q_FALLTHROUGH
  * Don't look for /etc/kderc every single time
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Don't build the kconfig_compiler tests when crosscompiling
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * [KConfigGroup] reserve() more and add some C++11
  * Deprecate KStandardShortcut::SaveOptions
  * Add apidox to KStandardShorcut::StandardShortcut
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Fix labels of DeleteFile/RenameFile actions
  * kconfigini: Strip leading whitespace when reading entry values.
  * KAuthorized: Fix API documentation for authorizeAction()
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Allow to build KConfig without Qt5Gui
  * autotests: fix the failures I got here.
  * Standard shortcuts: use Ctrl+PageUp/PageDown for prev/next tab.
  * API dox: fix QT_*_HOME notes (typo, wrong enum type, markup)
  * API dox: update url from kdelibs to kconfig
  * API dox: use @param for normal parameter listing, not @arg
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Fix for CMake 3.9.
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * tests: use QIODevice::Text in kconfigcompiler_test
  * tests: use right QProcess API in kconfigcompiler_test
  * API dox: note CamelCase includes by @class tag with more classes
* Tue May 30 2017 lbeltrame@kde.org
- Adjust license as pointed out during legal review
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix relativePath calculation in KDesktopFile::locateLocal() (kde#345100)
- Remove patches, now upstream:
  * fix-locateLocal.patch
* Wed Apr 26 2017 wbauer@tmo.at
- Add fix-locateLocal.patch to fix saving changes to submenus in
  kmenuedit (kde#345100)
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * explicitly set NO_CMAKE_FIND_ROOT_PATH
  * Remove unused QDateTime in KConfigBackend.
  * Now that kconfigbackend.h isn't installed anymore, rename it to _p.h for clarity.
  * Upgrade KF5 version to 5.33.0.
  * Sanitize shortcut list on read/write from kdeglobals
  * avoid useless reallocs by removing squeeze call on temporary buffer
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * KConfig: stop exporting and installing KConfigBackend.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * kconfig_compiler - generate code with overrides
  * Properly parse function keywords (kde#371562)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Make sure we don't break compilation with past broken units
  * Don't be fatal on File field not being properly parsed
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Fix memory leak in SignalsTestNoSingletonDpointer, found by ASAN
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Add Donate entry to KStandardShortcut
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Add DeleteFile and RenameFile standard shortcut
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Deprecate authorizeKAction() in favor of authorizeAction()
  * Fix reproducibility in builds by ensuring utf-8 encoding
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Avoid skipping KAuthorized check
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Add support for get QStandardPaths locations inside desktop files
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * KConfigIniBackend: Fix expensive detach in lookup
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Ensure group is unescaped properly in kconf_update
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Fix usage of ecm_create_qm_loader.
  * Fix include variable
  * Use KDE_INSTALL_FULL_ variant, so there is no ambiguity
  * Allow KConfig to use resources as fallback config files
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Mark kconfig-compiler as non-gui tool
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Optimize readEntryGui
  * Avoid QString::fromLatin1() in generated code
  * Minimize calls to expensive QStandardPaths::locateAll()
  * Finish the port to QCommandLineParser
    (it has addPositionalArgument now)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Sat Aug 15 2015 wbauer@tmo.at
- Add kconfig-desktop-translations.patch: read translations for
  .desktop files from desktop-translations if they are not in the
  file itself (boo#904524, boo#932158)
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Don't recommend to use deprecated API
  * Don't generate deprecated code
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Install kconfig_compiler into libexec
  * New code generation option TranslationDomain=, for use with
    TranslationSystem=kde; normally needed in libraries.
  * Make it possible to use kconfig_compiler from different sources
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Prevent crash if QWindow::screen() is null
  * Add KConfigGui::setSessionConfig() (kde#346768)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
- Drop 0001-ensure-platform-window-resize-processing.patch and
  0001-Add-KConfigGui-setSessionConfig.patch, merged upstream
- Delete 0001-ensure-platform-window-resize-processing.patch
* Sun May 17 2015 hrvoje.senjan@gmail.com
- Comment out 0001-ensure-platform-window-resize-processing.patch,
  causes bad side-effects (kde#344183,boo#931167)
* Tue May 12 2015 hrvoje.senjan@gmail.com
- Added 0001-Add-KConfigGui-setSessionConfig.patch (kde#346768)
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Generate QML-proof classes using the kconfigcompiler
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Fix assert when using KSharedConfig in a global object destructor.
  * kconfig_compiler: add support for CategoryLoggingName in *.kcfgc
    files, to generate qCDebug(category) calls.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * kconf_update no longer processes *.upd file from KDE SC 4.
    Add "Version=5" to top of the upd file for updates that should
    be applied to Qt5/KF5 applications
  * Fixed KCoreConfigSkeleton when toggling a value with
    saves in between
  * Fixed using KSharedConfig in global object destructor
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * KConfigLoader: fix sharing of KSharedConfig objects
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
- Added 0001-ensure-platform-window-resize-processing.patch for
  resolving https://bugreports.qt-project.org/browse/QTBUG-40584
  within KConfig Framework
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
- Harden required Qt5 libs versions
- Pass the location of lconvert executable
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Added libqt5-linguist-devel BuildRequires
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
- Droped 0001-Normalize-vars-to-avoid-odd-bugs-QT_REQUIRED_VERSION.patch,
  merged upstream
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Added 0001-Normalize-vars-to-avoid-odd-bugs-QT_REQUIRED_VERSION.patch,
  fixes build with CMake 3.0 rc2 (find_dependency macro needs passing
  of version)
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Wed Feb 19 2014 hrvoje.senjan@gmail.com
- Split out kconf_update helper to kconf_update5 package
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kconfig package
